/*******************************************************************************
 * Copyright (c) 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.target.internal.ide;

import java.net.URL;

import org.eclipse.core.runtime.*;
import org.eclipse.target.internal.ide.ui.IdeTargetAdapterFactory;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;

/**
 * The main plugin class to be used in the desktop.
 */
public class TargetIdePlugin extends AbstractUIPlugin {
	
	public static final String ID = "org.eclipse.target.ide"; //$NON-NLS-1$
	public static final String SITE_TYPE_ID = ID + ".site"; //$NON-NLS-1$
	
	// image paths
	public static final String ICON_PATH = "icons/basic/"; //$NON-NLS-1$
	
	//The shared instance.
	private static TargetIdePlugin plugin;
	
	/**
	 * The constructor.
	 */
	public TargetIdePlugin() {
		super();
		plugin = this;
	}

	/**
	 * This method is called upon plug-in activation
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);
		
		IdeTargetAdapterFactory factory = new IdeTargetAdapterFactory();
		Platform.getAdapterManager().registerAdapters(factory, IdeWorkspaceSite.class);
		Platform.getAdapterManager().registerAdapters(factory, IdeTargetResource.class);
	}

	/**
	 * This method is called when the plug-in is stopped
	 */
	public void stop(BundleContext context) throws Exception {
		super.stop(context);
	}

	/**
	 * Returns the shared instance.
	 */
	public static TargetIdePlugin getDefault() {
		return plugin;
	}
	
	public static void log(CoreException e) {
		log (e.getMessage(), e);
	}

	public static void log(String string, CoreException e) {
		getDefault().getLog().log(new Status(e.getStatus().getCode(), ID, 0, string, e));
	}
	
	public URL getImageURL(String location) {
		return TargetIdePlugin.getDefault().getBundle().getEntry(ICON_PATH + location);
	}
}
