/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.target.internal.ide.ui;

import org.eclipse.core.runtime.IAdapterFactory;
import org.eclipse.target.internal.ide.IdeTargetResource;
import org.eclipse.target.internal.ide.IdeWorkspaceSite;
import org.eclipse.target.internal.ui.SiteElement;
import org.eclipse.ui.model.IWorkbenchAdapter;
import org.eclipse.ui.progress.IDeferredWorkbenchAdapter;

/**
 * Factory for populating views that are showing target resources
 */
public class IdeTargetAdapterFactory implements IAdapterFactory {

	private SiteElement siteElement = new IdeSiteElement();
	private IdeTargetResouceElement targetResourceElement = new IdeTargetResouceElement();

	/* (non-Javadoc)
	 * @see org.eclipse.core.runtime.IAdapterFactory#getAdapter(java.lang.Object, java.lang.Class)
	 */
	public Object getAdapter(Object adaptableObject, Class adapterType) {
		if (IWorkbenchAdapter.class == adapterType) {
			return getWorkbenchAdapter(adaptableObject);
		}
		
		if(IDeferredWorkbenchAdapter.class == adapterType) {
			 Object o = getWorkbenchAdapter(adaptableObject);
			 if(o != null && o instanceof IDeferredWorkbenchAdapter) {
			 	return o;
			 }
			 return null;
		}
		
		return null;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.runtime.IAdapterFactory#getAdapterList()
	 */
	public Class[] getAdapterList() {
		return new Class[] {IWorkbenchAdapter.class, IDeferredWorkbenchAdapter.class};
	}

	protected Object getWorkbenchAdapter(Object o) {
		if (o instanceof IdeWorkspaceSite) {
			return siteElement;
		} else if (o instanceof IdeTargetResource) {
			return targetResourceElement;
		}
		return null;
	}
}
