/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.target.internal.iofile.ui;

import org.eclipse.jface.dialogs.IDialogSettings;
import org.eclipse.target.internal.iofile.IoFilePlugin;
import org.eclipse.target.internal.iofile.Policy;
import org.eclipse.target.ui.SiteCreationWizard;
import org.eclipse.target.ui.SiteCreationWizardPage;

/**
 * The file system configuration wizard used when associating a project
 * the the file system provider. It is registered as a Team configuration wizard
 * in the plugin.xml and is invoked when a user chooses to create a File System
 * Repository Provider. One invoked, this wizard makes use of the <code>FileSystemMainPage</code>
 * in order to obtain a target locaton on disk.
 */
public class IoFileSiteCreationWizard extends SiteCreationWizard {
	
	IoFileSiteCreationWizardPage mainPage;
	
	public IoFileSiteCreationWizard() {
		// retrieve the remembered dialog settings
		IDialogSettings workbenchSettings = IoFilePlugin.getDefault().getDialogSettings();
		IDialogSettings section = workbenchSettings.getSection("ProviderExamplesWizard"); //$NON-NLS-1$
		if (section == null) {
			section = workbenchSettings.addNewSection("ProviderExamplesWizard"); //$NON-NLS-1$
		}
		setDialogSettings(section);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.target.ui.SiteCreationWizard#createSitePage()
	 */
	protected SiteCreationWizardPage createSitePage() {
		return new IoFileSiteCreationWizardPage(
				"FileSystemMainPage", //$NON-NLS-1$
				Policy.bind("ConfigurationWizard.name"),  //$NON-NLS-1$
				Policy.bind("ConfigurationWizard.description"),  //$NON-NLS-1$
				null);
	}

	/*
	 * @see org.eclipse.jface.wizard.IWizard#getWindowTitle()
	 */
	public String getWindowTitle() {
		return "New File System Site";
	}
	
}
