/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.target.internal.ui;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IAdaptable;
import org.eclipse.jface.dialogs.ErrorDialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.*;
import org.eclipse.target.AuthenticatedSite;
import org.eclipse.target.Site;
import org.eclipse.target.internal.TargetMessages;
import org.eclipse.ui.dialogs.PropertyPage;

public class AuthenticatedSitePropertiesPage extends PropertyPage {
	public static final int WIDTH_HINT = 250;
	
	private Site site;
	private Text nameText, passwordText;

	/**
	 * Initializes the page
	 */
	private void initialize() {
		IAdaptable element = getElement();
		if (element instanceof Site) {
			site = (Site)element;
		} else {
			Site adapter = (Site)element.getAdapter(Site.class);
			if (adapter != null) {
				site = adapter;
			}
		}
	}

	/**
	 * @see org.eclipse.jface.preference.PreferencePage#createContents(Composite)
	 */
	protected Control createContents(Composite parent) {
		initialize();
		Composite container = new Composite(parent, SWT.NONE);
		container.setLayout(new GridLayout(2, false));

		Label serverLabel = new Label(container, SWT.NONE);
		serverLabel.setText(TargetMessages.AuthenticatedTargetSitePropertiesPage_Server); //$NON-NLS-1$
		serverLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_END));
		Label serverText = new Label(container, SWT.NONE);
		serverText.setText(site.getLocation());
		GridData data = new GridData();
		data.widthHint = WIDTH_HINT;
		serverText.setLayoutData(data);

		Label nameLabel = new Label(container, SWT.NONE);
		nameLabel.setText(TargetMessages.AuthenticatedTargetSitePropertiesPage_User); //$NON-NLS-1$
		nameLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_END));
		nameText = new Text(container, SWT.SINGLE | SWT.BORDER);
		data = new GridData();
		data.widthHint = WIDTH_HINT;
		nameText.setLayoutData(data);
		String name=((AuthenticatedSite)site).getUsername();
		if (name!=null) nameText.setText(name);

		Label passwordLabel = new Label(container, SWT.NONE);
		passwordLabel.setText(TargetMessages.AuthenticatedTargetSitePropertiesPage_Password); //$NON-NLS-1$
		passwordLabel.setLayoutData(new GridData(GridData.HORIZONTAL_ALIGN_END));
		passwordText = new Text(container, SWT.SINGLE | SWT.BORDER | SWT.PASSWORD);
		String pass=((AuthenticatedSite)site).getPassword();
		if (pass!=null) 
			passwordText.setText(pass);
		else
			passwordText.setText(""); //$NON-NLS-1$
		data = new GridData();
		data.widthHint = WIDTH_HINT;
		passwordText.setLayoutData(data);

		return container;
	}

	/**
	 * @see org.eclipse.jface.preference.IPreferencePage#performOk()
	 */
	public boolean performOk() {
		String name = nameText.getText();
		String password = passwordText.getText();
		try {
			if (name!=null && name.length()>0) {
				((AuthenticatedSite)site).setUsername(name);
				if (password!=null && password.length()>0) 
					((AuthenticatedSite)site).setPassword(password);
				else 
					((AuthenticatedSite)site).setPassword(""); //$NON-NLS-1$
			}
			return true;
		} catch (CoreException e) {
			ErrorDialog.openError(getShell(), TargetMessages.AuthenticatedTargetSitePropertiesPage_Error, null, e.getStatus()); //$NON-NLS-1$
			return false;
		}
	}

}
