/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.target.internal.ui;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.jface.viewers.ITableLabelProvider;
import org.eclipse.osgi.util.NLS;
import org.eclipse.swt.graphics.Image;
import org.eclipse.target.ITargetResource;
import org.eclipse.target.internal.TargetMessages;
import org.eclipse.target.internal.TargetPlugin;
import org.eclipse.ui.model.WorkbenchLabelProvider;

public class SiteExplorerViewLabelProvider extends WorkbenchLabelProvider implements ITableLabelProvider {

	public Image getColumnImage(Object element, int columnIndex) {
		if (columnIndex == 0) {
			return super.getImage(element);
		}
		return null;
	}
	public String getColumnText(Object element, int columnIndex) {		
		switch (columnIndex) {
			case 0 :
				return super.getText(element);
			case 1 :
				if(element instanceof ITargetResource) {
					ITargetResource remote = ((ITargetResource)element);
					if(remote.isDirectory()) {
						return ""; //$NON-NLS-1$
					}
					long size = remote.getSize();
					int sizeKb = (int)(size / 1000);
					if(sizeKb == 0 && size % 1000 > 0) {
						sizeKb = 1;
					}
     				return NLS.bind(TargetMessages.SiteExplorerViewLabelProvider_fileSize, new Object[] { new Integer(sizeKb).toString() });						 //$NON-NLS-1$
				}
			case 2 :
				if(element instanceof ITargetResource) {
					try {
						return ((ITargetResource)element).getProperty(ITargetResource.LAST_MODIFIED_TIMESTAMP_PROPERTY);
					} catch (CoreException e) {
						TargetPlugin.log(e);
						return "N/A";
					}
				}
			case 3 :
				if(element instanceof ITargetResource) {
					return ((ITargetResource)element).getFullPath();
				}
		}
		return ""; //$NON-NLS-1$
	}
}
