/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.team.internal.ftp;

import java.net.MalformedURLException;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.ftp.FtpException;
import org.eclipse.team.core.TeamException;

/**
 * Wraps FtpExceptions in a TeamException
 */
public class FTPException extends TeamException {

    /**
     * Comment for <code>serialVersionUID</code>
     */
    private static final long serialVersionUID = 1L;

    public FTPException(IStatus status) {
		super(status);
	}
	
	public FTPException(String message) {
		super(new Status(IStatus.ERROR, FTPPlugin.ID, UNABLE, message, null));
	}

	public FTPException(String message, int code) {
		this(new Status(IStatus.ERROR, FTPPlugin.ID, code, message, null));
	}
	
	public FTPException(String message, MalformedURLException e) {
		this(new Status(IStatus.ERROR, FTPPlugin.ID, 0, message, e));
	}

	/*
	 * Static helper methods for creating exceptions
	 */
	public static FTPException wrapException(String message, CoreException e) {
		return new FTPException(new Status(IStatus.ERROR, FTPPlugin.ID, e.getStatus().getCode(), message, e));
	}

	public static FTPException wrapException(FtpException e) {
		// TODO: may bury exceptions
		return new FTPException(new Status(IStatus.ERROR, FTPPlugin.ID, e.getStatus().getCode(), e.getMessage(), e));
	}

}
